@@ -1,9 +1,13 @@
 use crate::Config;
-use std::{fmt::Display, io, process::ExitStatus, string::FromUtf8Error, sync::Arc};
+use std::{ffi::OsString, fmt::Display, io, process::ExitStatus, string::FromUtf8Error, sync::Arc};
 
 #[derive(Debug, Clone)]
 pub enum Error {
     NoArgumentsGiven,
+    FileNotFoundWhenExecuting {
+        executable: OsString,
+        source: Arc<io::Error>,
+    },
     CommandIoError {
         message: String,
         source: Arc<io::Error>,
@@ -32,6 +36,7 @@ impl Error {
 }
 
 #[doc(hidden)]
+#[rustversion::attr(since(1.46), track_caller)]
 pub fn panic_on_error<T>(result: Result<T, Error>) -> T {
     match result {
         Ok(t) => t,
@@ -43,6 +48,11 @@ impl Display for Error {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
             Error::NoArgumentsGiven => write!(f, "no arguments given"),
+            Error::FileNotFoundWhenExecuting { executable, .. } => write!(
+                f,
+                "File not found error when executing '{}'",
+                executable.to_string_lossy()
+            ),
             Error::CommandIoError { message, .. } => write!(f, "{}", message),
             Error::NonZeroExitCode {
                 full_command,
@@ -71,7 +81,8 @@ impl Display for Error {
 impl std::error::Error for Error {
     fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
         match self {
-            Error::CommandIoError { source, .. } => Some(&**source),
+            Error::FileNotFoundWhenExecuting { source, .. }
+            | Error::CommandIoError { source, .. } => Some(&**source),
             Error::InvalidUtf8ToStdout { source, .. }
             | Error::InvalidUtf8ToStderr { source, .. } => Some(&**source),
             Error::NoArgumentsGiven | Error::NonZeroExitCode { .. } => None,
